#
# spec file for package perl-Minion-Backend-SQLite
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Minion-Backend-SQLite
Name:           perl-Minion-Backend-SQLite
Version:        5.0.7
Release:        1.6
License:        Artistic-2.0
Summary:        SQLite backend for Minion job queue
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DB/DBOOK/%{cpan_name}-v%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Minion) >= 10.13
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(Module::Metadata)
BuildRequires:  perl(Mojo::SQLite) >= 3.000
BuildRequires:  perl(Mojolicious) >= 7.49
BuildRequires:  perl(Test::More) >= 0.96
Requires:       perl(Minion) >= 10.13
Requires:       perl(Mojo::SQLite) >= 3.000
Requires:       perl(Mojolicious) >= 7.49
%{perl_requires}

%description
Minion::Backend::SQLite is a backend for Minion based on Mojo::SQLite. All
necessary tables will be created automatically with a set of migrations
named 'minion'. If no connection string or ':temp:' is provided, the
database will be created in a temporary directory.

%prep
%autosetup  -n %{cpan_name}-v%{version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples prereqs.yml README
%license LICENSE

%changelog
* Sun Aug 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.7
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.7    2022-08-13 13:00:35 EDT
  - Add workers field to stats method (#21, Oliver Kurz)
* Sat Nov 13 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.6
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.6    2021-11-12 19:39:19 EST
  - Improve efficiency of stats query (#19, Sebastian Riedel)
* Wed Jun 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.5
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.5    2021-06-15 21:18:41 EDT
  - Support min_priority option in dequeue method.
  - Update IRC metadata to libera.chat
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.4
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.4    2021-02-16 13:30:11 EST
  - Use Mojo::Promise in tests instead of the deprecated and decored Mojo::IOLoop::Delay (#17, Stefan Adams)
* Mon Aug  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.3
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.3    2020-08-02 18:15:20 EDT
  - Minion requirement bumped to 10.13.
  - Removed experimental support for job sequences.
  - Added EXPERIMENTAL expire option to enqueue method to support expiring jobs.
  - Added EXPERIMENTAL lax option to enqueue method to support lax dependencies.
  - Removed next and previous fields from list_jobs method.
  - Added expires and lax fields to list_jobs method.
  - Fixed a bug where manual retries would count towards the attempts limit for automatic retries.
  - Optimized checking parent job state in job dequeue.
* Tue Jul 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.2
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.2    2020-07-23 00:30:45 EDT
  - Minion requirement bumped to 10.10.
  - Support removing stuck jobs in repair method.
  - Added EXPERIMENTAL sequence option to enqueue method and sequences option to list_jobs method
    to support job sequences.
  - Added next and previous fields to list_jobs method.
* Fri Jun 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.1
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.1    2020-06-17 23:20:46 EDT
  - Fixed tests to be less sensitive to error message contents.
* Wed Jun 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 5.0.0
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  v5.0.0    2020-06-17 01:22:45 EDT
  - Minion requirement bumped to 10.03.
  - Changed reset method to require options for what to reset and allow for
    locks to be reset without resetting the whole queue.
  - Added before options to list_jobs and list_workers methods to support
    iterating jobs and workers.
* Tue Aug  6 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.005
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  4.005     2019-08-05 11:00:01 EDT
  - Allow fields to be removed with note method.
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.004
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  4.004     2019-07-09 00:53:20 EDT
  - Add time field to list_jobs method.
* Sat Jun 22 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 4.003
  see /usr/share/doc/packages/perl-Minion-Backend-SQLite/Changes
  4.003     2019-06-21 18:06:07 EDT
  - Ignore missing workers for jobs in the minion_foreground named queue to
    make debugging very slow jobs easier.
* Wed Oct 10 2018 Stephan Kulow <coolo@suse.com>
- initial package 4.002
  * created by cpanspec 1.78.08
